@@ -1,5 +1,10 @@
 '''
 Window Pygame: windowing provider based on Pygame
+
+.. warning::
+
+    Pygame has been deprecated and will be removed in the release after Kivy
+    1.11.0.
 '''
 
 __all__ = ('WindowPygame', )
@@ -33,6 +38,11 @@ glReadPixels = GL_RGBA = GL_UNSIGNED_BYTE = None
 
 class WindowPygame(WindowBase):
 
+    @deprecated(
+        msg='Pygame has been deprecated and will be removed after 1.11.0')
+    def __init__(self, *largs, **kwargs):
+        super(WindowPygame, self).__init__(*largs, **kwargs)
+
     def create_window(self, *largs):
         # ensure the mouse is still not up after window creation, otherwise, we
         # have some weird bugs
@@ -191,7 +201,7 @@ class WindowPygame(WindowBase):
 
     def close(self):
         pygame.display.quit()
-        self.dispatch('on_close')
+        super(WindowPygame, self).close()
 
     def on_title(self, instance, value):
         if self.initialized:
